@@ -618,7 +618,7 @@ let map_filename_to_mime_type filename =
     | "aac" -> "audio/x-aac"
     | "aif" | "aiff" | "aifc" -> "audio/x-aiff"
     | "caf" -> "audio/x-caf"
-    | "flac" -> "audio/x-flac"
+    | "flac" -> "audio/flac"
     | "mka" -> "audio/x-matroska"
     | "m3u" -> "audio/x-mpegurl"
     | "wax" -> "audio/x-ms-wax"
@@ -774,5 +774,6 @@ let map_filename_to_mime_type filename =
     | "ice" -> "x-conference/x-cooltalk"
     | "nef" -> "image/x-nikon-nef"
     | "gz" -> "application/x-gzip"
+    | "m4a" -> "audio/mp4"
     | _ -> "application/octet-stream"
 
